@@ -220,20 +220,12 @@ def normalize_address(orig, v6):
 
 def open_file_read(fn):
     '''Opens the specified file read-only'''
-    try:
-        orig = open(fn, 'r')
-    except Exception:
-        raise
-
-    return orig
+    return open(fn, 'r')
 
 
 def open_files(fn):
     '''Opens the specified file read-only and a tempfile read-write.'''
-    try:
-        orig = open_file_read(fn)
-    except Exception:
-        raise
+    orig = open_file_read(fn)
 
     try:
         (tmp, tmpname) = mkstemp()
@@ -277,16 +269,10 @@ def close_files(fns, update=True):
     os.close(fns['tmp'])
 
     if update:
-        try:
-            shutil.copystat(fns['origname'], fns['tmpname'])
-            shutil.copy(fns['tmpname'], fns['origname'])
-        except Exception:
-            raise
+        shutil.copystat(fns['origname'], fns['tmpname'])
+        shutil.copy(fns['tmpname'], fns['origname'])
 
-    try:
-        os.unlink(fns['tmpname'])
-    except OSError:
-        raise
+    os.unlink(fns['tmpname'])
 
 
 def cmd(command):
@@ -427,13 +413,10 @@ def get_ppid(mypid=os.getpid()):
     if not os.path.isfile(name):
         raise IOError("Couldn't find '%s'" % (name))
 
-    try:
-        # LP: #1101304
-        # 9983 (cmd) S 923 ...
-        # 9983 (cmd with spaces) S 923 ...
-        ppid = open(name).readlines()[0].split(')')[1].split()[1]
-    except Exception: # pragma: no cover
-        raise
+    # LP: #1101304
+    # 9983 (cmd) S 923 ...
+    # 9983 (cmd with spaces) S 923 ...
+    ppid = open(name).readlines()[0].split(')')[1].split()[1]
 
     return int(ppid)
 
@@ -729,8 +712,31 @@ def in_network(tested_add, tested_net, v6):
     return network == orig_network
 
 
-def get_iptables_version(exe="/bin/iptables"):
+# We prefer to hardcode the iptables dir in common.py, but we do not import
+# common.py here. While internally ufw always uses common.py to determine the
+# path, _find_system_iptables() is implemented for get_iptables_version() and
+# get_netfilter_capabilities() so as to not break API for external consumers
+# since these have historically used a default for 'exe'.
+def _find_system_iptables():
+    exe = ""
+    for d in ["/bin", "/bin",
+              "/usr/bin", "/usr/bin",
+              "/usr/local/bin", "/usr/local/bin"]:
+        exe = os.path.join(d, "iptables")
+        if os.path.exists(exe):
+            break
+        else:
+            exe = ""
+    if exe == "":
+        raise OSError(errno.ENOENT, "Could not find iptables")
+    return exe
+
+
+def get_iptables_version(exe=None):
     '''Return iptables version'''
+    if exe is None:
+        exe = _find_system_iptables()
+
     (rc, out) = cmd([exe, '-V'])
     if rc != 0:
         raise OSError(errno.ENOENT, "Error running '%s'" % (exe))
@@ -739,7 +745,7 @@ def get_iptables_version(exe="/bin/iptables"):
 
 
 # must be root, so don't report coverage in unit tests
-def get_netfilter_capabilities(exe="/bin/iptables", do_checks=True):
+def get_netfilter_capabilities(exe=None, do_checks=True):
     '''Return capabilities set for netfilter to support new features. Callers
        must be root.'''
     def test_cap(exe, chain, rule):
@@ -752,6 +758,9 @@ def get_netfilter_capabilities(exe="/bin/iptables", do_checks=True):
     if do_checks and os.getuid() != 0:
         raise OSError(errno.EPERM, "Must be root")
 
+    if exe is None:
+        exe = _find_system_iptables()
+
     caps = []
 
     chain = "ufw-caps-test"
